# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .hourly_weather_response_units import HourlyWeatherResponseUnits
from .hourly_conditions import HourlyConditions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class HourlyWeatherResponse(UniversalBaseModel):
    latitude: float
    longitude: float
    timezone: str
    utc_offset: int
    elevation: typing.Optional[int] = None
    units: HourlyWeatherResponseUnits
    hourly: typing.List[HourlyConditions]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
